Re: [PATCH] diff: release blobs after generating textual diff.
- From
Junio C Hamano <junkio@cox.net>
- Date
- May 8, 2007, 20:58 UTC
- Message-ID
- <7v7irj2fsn.fsf@assigned-by-dhcp.cox.net>
- In-Reply-To
- <200705062336.28201.robin.rosenberg.lists@dewire.com>
Robin Rosenberg <robin.rosenberg.lists@dewire.com> writes:
Show 26 quoted lines
> söndag 06 maj 2007 skrev Nicolas Pitre: >> On Sun, 6 May 2007, Junio C Hamano wrote: >> >> > This reduces the memory pressure when dealing with many paths. >> > >> > An unscientific test of running "diff-tree --stat --summary -M" >> > between v2.6.19 and v2.6.20-rc1 in the linux kernel repository >> > indicates that the number of minor faults are reduced by 2/3 >> > (153k vs 49k). >> > >> > Signed-off-by: Junio C Hamano <junkio@cox.net> >> > --- >> > >> > * This is still a WIP, not in the sense that it breaks anything >> > (it doesn't seem to), but in the sense that it is not known >> > if it is useful in general and would make that much of a >> > difference with a project much larger than the kernel. >> >> This can only be good. People are really starting to use Git with >> gigantic repos on limited memory hardware. > > This did wonders on the usually unreasonable diffs on huge > repos. The openoffice diff mentioned in the openoffice thread > went from 6 to ~3 minutes, and most importantly the computer > was perfectly usable meanwhile. Git memory usage dropped from > 1,7GB to 400MB.
I've parked a cleaned-up version in 'next'. Hopefully we can merge it to 'master' before 1.5.2, as it is not about a new feature but about fixing a performance 'bug'.